searchData={"items":[{"type":"module","title":"Tracee","doc":"This Elixir library offers functionality to trace and assert expected function\ncalls within concurrent Elixir processes.\n\nThis allows you to ensure that destructive and/or expensive functions are only\ncalled the expected number of times. For more information, see [the Elixir forum\npost](https://elixirforum.com/t/tracing-and-asserting-function-calls/63035) that\nmotivated the development of this library.","ref":"Tracee.html"},{"type":"module","title":"Usage - Tracee","doc":"defmodule ModuleTest do\n      use ExUnit.Case, async: true\n\n      import Tracee\n\n      setup :verify_on_exit!\n\n      describe \"fun/0\" do\n        test \"calls expensive function only once\" do\n          expect(AnotherModule, :expensive_fun, 1)\n\n          assert Module.fun()\n        end\n\n        test \"calls expensive function only once from another process\" do\n          expect(AnotherModule, :expensive_fun, 1)\n\n          assert fn -> Module.fun() end\n                 |> Task.async()\n                 |> Task.await()\n        end\n      end\n    end","ref":"Tracee.html#module-usage"},{"type":"function","title":"Tracee.expect/4","doc":"Sets an expectation for a function call with a specific arity and optional\ncount.","ref":"Tracee.html#expect/4"},{"type":"function","title":"Examples - Tracee.expect/4","doc":"- Expect `AnotherModule.expensive_fun/0` to be called once:\n\n      Tracee.expect(AnotherModule, :expensive_fun, 0)\n\n- Expect `AnotherModule.expensive_fun/1` to be called twice:\n\n      Tracee.expect(AnotherModule, :expensive_fun, 1, 2)\n\n- Expect `AnotherModule.expensive_fun/1` to be nerver called:\n\n      Tracee.expect(AnotherModule, :expensive_fun, 1, 0)","ref":"Tracee.html#expect/4-examples"},{"type":"function","title":"Tracee.start_link/0","doc":"Starts the tracer.","ref":"Tracee.html#start_link/0"},{"type":"function","title":"Tracee.verify/1","doc":"Verifies that all expected function calls have been received and nothing else.","ref":"Tracee.html#verify/1"},{"type":"function","title":"Tracee.verify_on_exit!/1","doc":"Registers a verification check to be performed when the current test process\nexits.","ref":"Tracee.html#verify_on_exit!/1"},{"type":"function","title":"Examples - Tracee.verify_on_exit!/1","doc":"defmodule ModuleTest do\n      use ExUnit.Case, async: true\n\n      import Tracee\n\n      setup :verify_on_exit!\n    end","ref":"Tracee.html#verify_on_exit!/1-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}